\name{trend}
\alias{trend}
\title{
Determine linear trends.
}
\description{
The function determines the trend from data of a single CM SAF netcdf input 
file basing on a linear model. Depending on the file size, this function 
could be very time consuming.
}
\usage{
trend(var, infile, outfile)
}
\arguments{
  \item{var}{
Name of netcdf variable (character).
}
  \item{infile}{
Filename of input netcdf file. This may include the directory (character). 
The file should include a time series of 2D fields to work in the desired way.
}
  \item{outfile}{
Filename of output netcdf file. This may include the directory (character).
}
}
\value{
A netcdf file including the trend data is written. An additional variable 
contains a measure for the significance of the calculated trends. 
}
\author{
Steffen Kothe
}
\examples{
## Create an example netcdf file with a similar structure
## as used by CM SAF. The file is created with the ncdf4 package.
## Alternatively example data can be freely downloaded here: https://wui.cmsaf.eu/

library(ncdf4)

## create some (non-realistic) example data

  lon <- seq(5,15,0.5)
  lat <- seq(45,55,0.5)
  time <- seq(as.Date("2000-01-01"), as.Date("2010-12-31"), "month")
  origin <- as.Date("1983-01-01 00:00:00")
  time <- as.numeric(difftime(time,origin,units="hour"))
  data <- array(250:350,dim=c(21,21,132))

## create example netcdf

   x <- ncdim_def(name="lon",units="degrees_east",vals=lon)
   y <- ncdim_def(name="lat",units="degrees_north",vals=lat)
   t <- ncdim_def(name="time",units="hours since 1983-01-01 00:00:00",
   vals=time,unlim=TRUE)
   var1 <- ncvar_def("SIS","W m-2",list(x,y,t),-1,prec="short")
   vars <- list(var1)
   ncnew <- nc_create("CMSAF_example_file.nc",vars)
   ncvar_put(ncnew,var1,data)
   ncatt_put(ncnew,"lon","standard_name","longitude",prec="text")
   ncatt_put(ncnew,"lat","standard_name","latitude",prec="text")
   nc_close(ncnew)

## Determine the trend of the example CM SAF netcdf file and write the 
## output to a new file.
   trend("SIS","CMSAF_example_file.nc", "CMSAF_example_file_trend.nc")
}
